#include <TZMainFrame.h>

//#ifdef __MAKECINT__
#pragma link C++ class TZMdiFrame+;
//#endif

ClassImp(TZMainFrame)

TZMainFrame::TZMainFrame (const TGWindow *p, UInt_t w, UInt_t h) : 
   TGMainFrame(p,w,h,kMainFrame | kVerticalFrame)
{
this->SetWindowName("ROOT Based Data Analysis Tool");
this->Connect("CloseWindow()", "TZMainFrame", this, "CloseWindow()");


//Create the menu entries
this->CreateMenuFile(); 
this->CreateMenuEdit(); 
this->CreateMenuView();
this->CreateMenuTools();
this->CreateMenuWindow();
this->CreateMenuHelp();

// menu bar item layout hints
fMenuBarItemLayout = new TGLayoutHints(kLHintsTop | kLHintsLeft, 0, 4, 0, 0);
fMenuBarHelpLayout = new TGLayoutHints(kLHintsTop | kLHintsRight);

  // menu bar
  fMenuBar = new TGMdiMenuBar(this,10,10);
  fMenuBar->AddPopup(new TGHotString("&File"),fMenuFile,fMenuBarItemLayout);
  fMenuBar->AddPopup(new TGHotString("&Edit"),fMenuEdit,fMenuBarItemLayout);
  fMenuBar->AddPopup(new TGHotString("&View"),fMenuView,fMenuBarItemLayout);
  fMenuBar->AddPopup(new TGHotString("&Tools"),fMenuTools,fMenuBarItemLayout);  
  fMenuBar->AddPopup(new TGHotString("&Window"),fMenuWindow,fMenuBarItemLayout);   
  fMenuBar->AddPopup(new TGHotString("&Help"),fMenuHelp,fMenuBarHelpLayout);
  this->AddFrame(fMenuBar,new TGLayoutHints(kLHintsTop | kLHintsExpandX,0,0,2,0));

  //Main Window
  fMain = new TGMdiMainFrame(this, fMenuBar, 1000, 700); 
  this->AddFrame(fMain,new TGLayoutHints(kLHintsExpandX|kLHintsExpandY));


  // status bar
  Int_t parts[] = {80, 5, 5, 10};
  fStatusBar = new TGStatusBar(this,50,10,kHorizontalFrame);
  fStatusBar->SetParts(parts,4);
  fStatusBar->SetText("Yesterday is history. Tomorrow is uncertain. Today is your day.",0); 
  this->AddFrame(fStatusBar,new TGLayoutHints(kLHintsBottom | kLHintsLeft |  kLHintsExpandX,0,0,2,0));

this->EnableDisableMenus();
this->MapSubwindows();
this->Resize(this->GetDefaultSize());
this->MapWindow();

}  

TZMainFrame::~TZMainFrame()
{
   this->Cleanup();
   gApplication->Terminate(0); 
}


  	
void TZMainFrame::CloseWindow()
{
   gApplication->Terminate(0);
}   	

void TZMainFrame::AddNewMdiFrame()
{
	TZMdiFrame *mdiFrame;
	mdiFrame = new TZMdiFrame(this->fMain, "New Document", fStatusBar);
	this->EnableDisableMenus();
}

void TZMainFrame::CreateMenuFile(){
  fMenuFile = new TGPopupMenu(gClient->GetRoot());
  fMenuFile->Connect("Activated(Int_t)", "TZMainFrame", this, "HandleMenu(Int_t)");
  fMenuFile->AddEntry("&New",M_FILE_NEW);
  fMenuFile->AddEntry("&Open...",M_FILE_OPEN);
  fMenuFile->AddEntry("Close",M_FILE_CLOSE);
  fMenuFile->AddSeparator();    
  fMenuFile->AddEntry("&Save",M_FILE_SAVE);
  fMenuFile->AddEntry("S&ave as...",M_FILE_SAVEAS);
  fMenuFile->AddSeparator();
  fMenuFile->AddEntry("&Print",M_FILE_PRINT);
  fMenuFile->AddEntry("P&rint setup...",M_FILE_PRINTSETUP);
  fMenuFile->AddSeparator();
  fMenuFile->AddEntry("E&xit",M_FILE_EXIT);
  
}


void TZMainFrame::CreateMenuEdit(){
	fMenuEdit = new TGPopupMenu(gClient->GetRoot());
  fMenuEdit->Connect("Activated(Int_t)", "TZMainFrame", this, "HandleMenu(Int_t)");
	fMenuEdit->AddEntry("Undo",M_EDIT_UNDO);
  fMenuEdit->AddSeparator(); 	
  fMenuEdit->AddEntry("Cut",M_EDIT_CUT);
  fMenuEdit->AddEntry("Copy",M_EDIT_COPY);
  fMenuEdit->AddEntry("Paste",M_EDIT_PASTE);
  fMenuEdit->AddSeparator();    
  fMenuEdit->AddEntry("Find",M_EDIT_FIND);
  fMenuEdit->AddEntry("Find Next",M_EDIT_FINDNEXT);
  fMenuEdit->AddEntry("Replace",M_EDIT_REPLACE);
}


void TZMainFrame::CreateMenuView(){
   fMenuView = new TGPopupMenu(gClient->GetRoot());
   fMenuView->Connect("Activated(Int_t)", "TZMainFrame", this, "HandleMenu(Int_t)");
   fMenuView->AddLabel("View Different Tabs");
   fMenuView->AddSeparator();   
   fMenuView->AddEntry("Node Editor", M_VIEW_NODEEDITOR);
   fMenuView->AddEntry("Generated Code", M_VIEW_CODE);
   fMenuView->AddEntry("Dependencies", M_VIEW_DEPENDENCIES);   
   fMenuView->AddEntry("Results", M_VIEW_RESULTS);

}


void TZMainFrame::CreateMenuTools(){
   fMenuTools = new TGPopupMenu(gClient->GetRoot());
   fMenuTools->Connect("Activated(Int_t)", "TZMainFrame", this, "HandleMenu(Int_t)");
   fMenuTools->AddEntry("Load from CSV File", M_TOOLS_LOAD_CSV_FILE);
   fMenuTools->AddEntry("Load from DB Table", M_TOOLS_LOAD_DB_TABLE);   
   fMenuTools->AddSeparator(); 
   fMenuTools->AddEntry("Customize... ", M_TOOLS_CUSTOMIZE);   
}

void TZMainFrame::CreateMenuWindow(){
   fMenuWindow = new TGPopupMenu(gClient->GetRoot());
   fMenuWindow->Connect("Activated(Int_t)", "TZMainFrame", this, "HandleMenu(Int_t)");
   fMenuWindow->AddEntry(new TGHotString("Tile &Horizontally"), M_WINDOW_HOR);
   fMenuWindow->AddEntry(new TGHotString("Tile &Vertically"), M_WINDOW_VERT);
   fMenuWindow->AddEntry(new TGHotString("&Cascade"), M_WINDOW_CASCADE);

}

void TZMainFrame::CreateMenuHelp(){
   fMenuHelp = new TGPopupMenu(gClient->GetRoot());
   fMenuHelp->Connect("Activated(Int_t)", "TZMainFrame", this, "HandleMenu(Int_t)");
   fMenuHelp->AddEntry("&Contents", M_HELP_CONTENTS);
   fMenuHelp->AddEntry("&Search...", M_HELP_SEARCH);
   fMenuHelp->AddSeparator();
   fMenuHelp->AddEntry("&About", M_HELP_ABOUT);
}


void TZMainFrame::EnableDisableMenus(){
  //fMenuEdit->GetListOfEntries()->R__FOR_EACH(TGMenuEntry, Delete) ();
  fMenuFile->DisableEntry(M_FILE_SAVE); 
  fMenuFile->DisableEntry(M_FILE_SAVEAS);
  fMenuFile->DisableEntry(M_FILE_PRINT);
  fMenuFile->DisableEntry(M_FILE_PRINTSETUP);
  
  fMenuView->CheckEntry(M_VIEW_NODEEDITOR);
}



void TZMainFrame::NewMenuItemActionPerformed(){
	this->AddNewMdiFrame() ;;
}

void TZMainFrame::OpenMenuItemActionPerformed(){
}

void TZMainFrame::CloseMenuItemActionPerformed(){
	this->fMain->Close(fMain->GetCurrent()) ;
}

void TZMainFrame::SaveMenuItemActionPerformed(){
}

void TZMainFrame::SaveAsMenuItemActionPerformed(){
}

void TZMainFrame::PrintMenuItemActionPerformed(){
}

void TZMainFrame::PrintSetupMenuItemActionPerformed(){
}

void TZMainFrame::ExitMenuItemActionPerformed(){
	//this->CloseWindow();  
  //delete this;
  gApplication->Terminate(0);   // terminate theApp no need to use SendCloseMessage()
}

  


void TZMainFrame::HandleMenu(Int_t id){
   // Handle menu items.

   switch (id) {
   	  case M_FILE_NEW:
   	      NewMenuItemActionPerformed();
   	      break;
   	  case M_FILE_OPEN:
   	      OpenMenuItemActionPerformed();
   	      break;   	      
      case M_FILE_CLOSE:
         CloseMenuItemActionPerformed();
         break;   	      
      case M_FILE_SAVE:
         SaveMenuItemActionPerformed();
         break;
      case M_FILE_SAVEAS:
         SaveAsMenuItemActionPerformed();
         break;
      case M_FILE_PRINT:
         PrintMenuItemActionPerformed();
         break;
      case M_FILE_PRINTSETUP:
         PrintSetupMenuItemActionPerformed();
         break;         
      case M_FILE_EXIT:
      	 ExitMenuItemActionPerformed();
         break;

      case M_TOOLS_LOAD_CSV_FILE:
      	 #ifndef STANDALONE 
      	    //gROOT->ProcessLine(".L LoadCSVfile.cpp");
      	 #endif
      	 //LoadCSVfile();
      	 #ifndef STANDALONE 
      	    //gROOT->ProcessLine(".U LoadCSVfile.cpp");
      	 #endif      	 
      	 break;
      case M_TOOLS_LOAD_DB_TABLE:
      	 break;
      case M_WINDOW_HOR:
         fMain->TileHorizontal();
         break;

      case M_WINDOW_VERT:
         fMain->TileVertical();
         break;

      case M_WINDOW_CASCADE:
         fMain->Cascade();
         break;

      default:
         //new MsgBox(gClient->GetRoot(), this, 400, 200, "No action for menu item " << id << "\n" );
         break;

   }
}



